summaryrefslogtreecommitdiff
path: root/src/commandline.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/commandline.cpp')
-rw-r--r--src/commandline.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/commandline.cpp b/src/commandline.cpp
index 507cc91f6..09fd9bfcd 100644
--- a/src/commandline.cpp
+++ b/src/commandline.cpp
@@ -1,10 +1,10 @@
/*
* The ManaPlus Client
* Copyright (C) 2004-2009 The Mana World Development Team
* Copyright (C) 2009-2010 The Mana Developers
* Copyright (C) 2011-2019 The ManaPlus Developers
*
* This file is part of The ManaPlus Client.
*
* This program is free software; you can redistribute it and/or modify
* it under the terms of the GNU General Public License as published by
@@ -41,16 +41,16 @@ static void printHelp()
{
std::cout <<
// TRANSLATORS: command line help
- _("manaplus [options] [manaplus-file]") <<
+ _("manaverse [options] [manaplus-file]") <<
std::endl << std::endl <<
// TRANSLATORS: command line help
- _("[manaplus-file] : The manaplus file is an XML file (.manaplus)") <<
+ _("[manaplus-file] : The manaverse file is an XML file (.manaplus)") <<
std::endl <<
// TRANSLATORS: command line help
_(" used to set custom parameters") <<
std::endl <<
// TRANSLATORS: command line help
- _(" to the manaplus client.") <<
+ _(" to the manaverse client.") <<
std::endl << std::endl <<
// TRANSLATORS: command line help
_("Options:") <<
@@ -133,7 +133,7 @@ static void printHelp()
static void printVersion()
{
std::cout <<
- strprintf("ManaPlus client %s", FULL_VERSION) <<
+ strprintf("ManaVerse client %s", FULL_VERSION) <<
std::endl;
}
@@ -1,10 +1,10 @@
/*
- * The ManaPlus Client
+ * The ManaVerse Client
* Copyright (C) 2004-2009 The Mana World Development Team
* Copyright (C) 2009-2010 The Mana Developers
@@ -1,10 +1,10 @@
* Copyright (C) 2011-2019 The ManaPlus Developers
*
- * This file is part of The ManaPlus Client.
+ * This file is part of The ManaVerse Client.
*
* This program is free software; you can redistribute it and/or modify